@@ -1,4 +1,5 @@
 from .admin import InlineHasAddPermissionsTransformer
+from .decorators import AvailableAttrsTransformer, ContextDecoratorTransformer
 from .encoding import (
     ForceTextTransformer,
     SmartTextTransformer,
@@ -13,6 +14,7 @@ from .http import (
     IsSafeUrlTransformer,
 )
 from .lru_cache import LRUCacheTransformer
+from .models import ModelsPermalinkTransformer
 from .os_utils import AbsPathTransformer
 from .shortcuts import RenderToResponseTransformer
 from .translations import (
@@ -26,6 +28,8 @@ from .urls import URLTransformer
 
 __all__ = (
     "AbsPathTransformer",
+    "AvailableAttrsTransformer",
+    "ContextDecoratorTransformer",
     "ForceTextTransformer",
     "HttpUrlQuotePlusTransformer",
     "HttpUrlQuoteTransformer",
@@ -34,6 +38,7 @@ __all__ = (
     "InlineHasAddPermissionsTransformer",
     "IsSafeUrlTransformer",
     "LRUCacheTransformer",
+    "ModelsPermalinkTransformer",
     "RenderToResponseTransformer",
     "SmartTextTransformer",
     "UGetTextLazyTransformer",
