@@ -182,10 +182,13 @@ def test_deprecated_in_mapping():
         (2, 1): ["InlineHasAddPermissionsTransformer"],
         (2, 0): [
             "AbsPathTransformer",
+            "AvailableAttrsTransformer",
+            "ContextDecoratorTransformer",
             "LRUCacheTransformer",
             "RenderToResponseTransformer",
             "UnicodeCompatibleTransformer",
         ],
+        (1, 11): ["ModelsPermalinkTransformer"],
     }
 
 
@@ -210,9 +213,12 @@ def test_removed_in_mapping():
         ],
         (3, 0): [
             "AbsPathTransformer",
+            "AvailableAttrsTransformer",
+            "ContextDecoratorTransformer",
             "InlineHasAddPermissionsTransformer",
             "LRUCacheTransformer",
             "RenderToResponseTransformer",
             "UnicodeCompatibleTransformer",
         ],
+        (2, 1): ["ModelsPermalinkTransformer"],
     }
